============
django-nani
============

.. warning:: django-nani is still in early alpha status, please use it with
             caution. 

******************
About this project
******************

This project is yet another attempt at making model translations suck less in
Django.

Features
--------

* Tested (on Django 1.2 through Django trunk and Python 2.5, 2.6 and 2.7 as well
  as PyPy 1.5, check http://ci.django-cms.org/job/django-nani/)
* Documented (check out http://django-nani.readthedocs.org)
* Simple API 
* Predictable
* Reliable
* Fast (few and simple queries)
* High level (no custom SQL Compiler or other scary things)

Please refer to the documentation at http://django-nani.readthedocs.org for more
information.